@@ -1,6 +1,5 @@
-/* $Xorg: locking.c,v 1.5 2001/02/09 02:03:40 xorgcvs Exp $ */
 /*
- 
+
 Copyright 1992, 1998  The Open Group
 
 Permission to use, copy, modify, distribute, and sell this software and its
@@ -24,7 +23,6 @@ used in advertising or otherwise to promote the sale, use or other dealings
 in this Software without prior written authorization from The Open Group.
 
 */
-/* $XFree86: xc/lib/X11/locking.c,v 1.5 2003/04/13 19:22:22 dawes Exp $ */
 
 /*
  * Author: Stephen Gildea, MIT X Consortium
@@ -47,11 +45,23 @@ in this Software without prior written authorization from The Open Group.
 #include <dlfcn.h>
 #endif
 
+#include "Xprivate.h"
 #include "locking.h"
 #ifdef XTHREADS_WARN
 #include <stdio.h>		/* for warn/debug stuff */
 #endif
 
+/* Additional arguments for source code location lock call was made from */
+#if defined(XTHREADS_WARN) || defined(XTHREADS_FILE_LINE)
+# define XTHREADS_FILE_LINE_ARGS \
+    ,								\
+    char* file,			/* source file, from macro */	\
+    int line
+#else
+# define XTHREADS_FILE_LINE_ARGS /* None */
+#endif
+
+
 #define NUM_FREE_CVLS 4
 
 /* in lcWrap.c */
@@ -60,14 +70,14 @@ extern LockInfoPtr _Xi18n_lock;
 #ifdef WIN32
 static DWORD _X_TlsIndex = (DWORD)-1;
 
-void _Xthread_init()
+void _Xthread_init(void)
 {
     if (_X_TlsIndex == (DWORD)-1)
 	_X_TlsIndex = TlsAlloc();
 }
 
 struct _xthread_waiter *
-_Xthread_waiter()
+_Xthread_waiter(void)
 {
     struct _xthread_waiter *me;
 
@@ -89,28 +99,18 @@ static xthread_t _Xthread_self(void)
 static LockInfoRec global_lock;
 static LockInfoRec i18n_lock;
 
-#if defined(XTHREADS_WARN) || defined(XTHREADS_FILE_LINE)
-static void _XLockMutex(lip,file,line)
-    LockInfoPtr lip;
-    char* file;
-    int line;
-#else
 static void _XLockMutex(
-    LockInfoPtr lip)
-#endif
+    LockInfoPtr lip
+    XTHREADS_FILE_LINE_ARGS
+    )
 {
     xmutex_lock(lip->lock);
 }
 
-#if defined(XTHREADS_WARN) || defined(XTHREADS_FILE_LINE)
 static void _XUnlockMutex(
-    LockInfoPtr lip,
-    char* file,
-    int line)
-#else
-static void _XUnlockMutex(
-    LockInfoPtr lip)
-#endif
+    LockInfoPtr lip
+    XTHREADS_FILE_LINE_ARGS
+    )
 {
     xmutex_unlock(lip->lock);
 }
@@ -202,15 +202,10 @@ static void _XLockDisplayWarn(
 }
 #endif /* XTHREADS_WARN */
 
-#if defined(XTHREADS_WARN) || defined(XTHREADS_FILE_LINE)
-static void _XUnlockDisplay(dpy,file,line)
-    Display *dpy;
-    char *file;
-    int line;
-#else
 static void _XUnlockDisplay(
-    Display *dpy)
-#endif
+    Display *dpy
+    XTHREADS_FILE_LINE_ARGS
+    )
 {
 #ifdef XTHREADS_WARN
     xthread_t self = xthread_self();
@@ -330,23 +325,17 @@ static void _XPopReader(
     }
 }
 
-#if defined(XTHREADS_WARN) || defined(XTHREADS_FILE_LINE)
-static void _XConditionWait(cv, mutex,file,line)
-    xcondition_t cv;
-    xmutex_t mutex;
-    char *file;
-    int line;
-#else
 static void _XConditionWait(
     xcondition_t cv,
-    xmutex_t mutex)
-#endif
+    xmutex_t mutex
+    XTHREADS_FILE_LINE_ARGS
+    )
 {
 #ifdef XTHREADS_WARN
     xthread_t self = xthread_self();
     char *old_file = locking_file;
     int old_line = locking_line;
-    
+
 #ifdef XTHREADS_DEBUG
     printf("line %d thread %x in condition wait\n", line, self);
 #endif
@@ -381,15 +370,10 @@ static void _XConditionWait(
 #endif /* XTHREADS_WARN */
 }
 
-#if defined(XTHREADS_WARN) || defined(XTHREADS_FILE_LINE)
-static void _XConditionSignal(cv,file,line)
-    xcondition_t cv;
-    char *file;
-    int line;
-#else
 static void _XConditionSignal(
-    xcondition_t cv)
-#endif
+    xcondition_t cv
+    XTHREADS_FILE_LINE_ARGS
+    )
 {
 #ifdef XTHREADS_WARN
 #ifdef XTHREADS_DEBUG
@@ -398,17 +382,12 @@ static void _XConditionSignal(
 #endif
     xcondition_signal(cv);
 }
-    
 
-#if defined(XTHREADS_WARN) || defined(XTHREADS_FILE_LINE)
-static void _XConditionBroadcast(cv,file,line)
-    xcondition_t cv;
-    char *file;
-    int line;
-#else
+
 static void _XConditionBroadcast(
-    xcondition_t cv)
-#endif
+    xcondition_t cv
+    XTHREADS_FILE_LINE_ARGS
+    )
 {
 #ifdef XTHREADS_WARN
 #ifdef XTHREADS_DEBUG
@@ -417,7 +396,7 @@ static void _XConditionBroadcast(
 #endif
     xcondition_broadcast(cv);
 }
-    
+
 
 static void _XFreeDisplayLock(
     Display *dpy)
@@ -469,15 +448,10 @@ static void _XDisplayLockWait(
     }
 }
 
-#if defined(XTHREADS_WARN) || defined(XTHREADS_FILE_LINE)
-static void _XLockDisplay(dpy, file, line)
-    Display *dpy;
-    char *file;			/* source file, from macro */
-    int line;
-#else
 static void _XLockDisplay(
-    Display *dpy)
-#endif
+    Display *dpy
+    XTHREADS_FILE_LINE_ARGS
+    )
 {
 #ifdef XTHREADS_WARN
     _XLockDisplayWarn(dpy, file, line);
@@ -486,23 +460,19 @@ static void _XLockDisplay(
 #endif
     if (dpy->lock->locking_level > 0)
 	_XDisplayLockWait(dpy);
+    _XIDHandler(dpy);
+    _XSeqSyncFunction(dpy);
 }
 
 /*
  * _XReply is allowed to exit from select/poll and clean up even if a
  * user-level lock is in force, so it uses this instead of _XFancyLockDisplay.
  */
-#if defined(XTHREADS_WARN) || defined(XTHREADS_FILE_LINE)
-static void _XInternalLockDisplay(dpy, wskip, file, line)
-    Display *dpy;
-    Bool wskip;
-    char *file;			/* source file, from macro */
-    int line;
-#else
 static void _XInternalLockDisplay(
     Display *dpy,
-    Bool wskip)
-#endif
+    Bool wskip
+    XTHREADS_FILE_LINE_ARGS
+    )
 {
 #ifdef XTHREADS_WARN
     _XLockDisplayWarn(dpy, file, line);
@@ -597,7 +567,7 @@ xthread_t (*_x11_thr_self)() = __x11_thr_self;
 #endif
 
 
-Status XInitThreads()
+Status XInitThreads(void)
 {
     if (_Xglobal_lock)
 	return 1;
@@ -646,7 +616,7 @@ Status XInitThreads()
 }
 
 #else /* XTHREADS */
-Status XInitThreads()
+Status XInitThreads(void)
 {
     return 0;
 }
